Convert a formula to a named character vector in analogy tasks.
Arguments
- formula
a formula object that defines the relationship between words using
+or-operators.
Value
a named character vector to be passed to similarity().
Convert a formula to a named character vector in analogy tasks.
a formula object that defines the relationship between words
using + or - operators.
a named character vector to be passed to similarity().