Compute the probability of words given other words.
Arguments
- x
a trained
textmodel_wordvectorobject.- targets
words for which probabilities are computed.
- layer
the layer based on which probabilities are computed.
- mode
specify the type of resulting object.
- ...
passed to
as.matrix().
Value
a matrix of words or documents sorted in descending order by the probability
scores when mode = "character"; a matrix of the probability scores when mode = "numeric".
When targets is a named numeric vector, probability scores are weighted by
the values.