| as.matrix.textmodel_doc2vec | R Documentation |
Extract word or document vectors from a textmodel_word2vec or textmodel_doc2vec object.
## S3 method for class 'textmodel_doc2vec'
as.matrix(
x,
normalize = TRUE,
layer = c("documents", "words"),
group = FALSE,
...
)
## S3 method for class 'textmodel_word2vec'
as.matrix(x, normalize = TRUE, layer = "words", padding = FALSE, ...)
x |
a |
normalize |
if |
layer |
the layer from which the vectors are extracted. |
group |
[experimental] average sentence or paragraph vectors from the same document.
Silently ignored when |
... |
not used. |
padding |
if |
a matrix that contain the word or document vectors in rows.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.