Compute the probability of words given other words.
a trained textmodel_wordvector object.
words for which probabilities are computed.
the layer based on which probabilities are computed.
specify the type of resulting object.
passed to as.matrix().
a matrix of words or documents sorted in descending order by the probability
scores when mode = "character"; a matrix of the probability scores when mode = "numeric".
When words is a named numeric vector, probability scores are weighted by
the values.