similarity: Compute similarity between word vectors
Description
Compute similarity between word vectors
Usage
similarity(x, words, mode = c("simil", "word"))Value
a matrix of cosine similarity scores when mode = "simil" or of
words sorted by the similarity scores when mode = "word.
Arguments
- x
a textmodel_wordvector object.
- words
words for which similarity is computed.
- mode
specify the type of resulting object.